# pydecorator

[![PyPI version shields.io](https://img.shields.io/pypi/v/pydecorator.svg)](https://pypi.python.org/pypi/pydecorator/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/pydecorator.svg)](https://pypi.python.org/pypi/pydecorator/)
[![PyPI license](https://img.shields.io/pypi/l/pydecorator.svg)](https://pypi.python.org/pypi/pydecorator/)

Useful Python decorator functions that facilitate a variety of tasks

# Installation

Use `pip` via [PyPi](https://pypi.org)

```bash
pip install pydecorator
```
**Or** use `git`

```bash
git clone git://github.com/luciancooper/pydecorator.git pydecorator
cd pydecorator
python setup.py install
```

# Documentation

Full documentation can be found [here](https://pydecorator.readthedocs.io)
